@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-featurestore-runtime service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_featurestore_runtime/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_featurestore_runtime/type_defs/)
 
 Usage::
 
@@ -14,8 +14,6 @@ Usage::
 import sys
 from typing import Dict, List, Sequence
 
-from typing_extensions import NotRequired
-
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
